@@ -2,9 +2,11 @@ import ast
 import sys
 import string
 from collections import deque
+from typing import Tuple, Union
 
 import astor
 
+from flynt import state
 from flynt.exceptions import FlyntException, ConversionRefused
 
 
@@ -49,11 +51,19 @@ def matching_call(node) -> bool:
 stdlib_parse = string.Formatter().parse
 
 
-def joined_string(fmt_call: ast.Call) -> ast.JoinedStr:
+def joined_string(fmt_call: ast.Call) -> Tuple[Union[ast.JoinedStr, ast.Str], bool]:
     """ Transform a "...".format() call node into a f-string node. """
 
     string = fmt_call.func.value.s
     var_map = {kw.arg: kw.value for kw in fmt_call.keywords}
+    inserted_value_nodes = []
+    for a in fmt_call.args:
+        inserted_value_nodes += list(ast.walk(a))
+    for kw in fmt_call.keywords:
+        inserted_value_nodes += list(ast.walk(kw.value))
+    str_in_str = any(
+        isinstance(n, (ast.Str, ast.JoinedStr)) for n in inserted_value_nodes
+    )
 
     for i, val in enumerate(fmt_call.args):
         var_map[i] = val
@@ -91,18 +101,22 @@ def joined_string(fmt_call: ast.Call) -> ast.JoinedStr:
         else:
             identifier = var_name
 
-        try:
-            ast_name = var_map.pop(identifier)
-        except KeyError as e:
-            raise ConversionRefused(
-                f"A variable {identifier} is used multiple times - better not to replace it."
-            ) from e
+        if state.aggressive:
+            ast_name = var_map[identifier]
+        else:
+            try:
+
+                ast_name = var_map.pop(identifier)
+            except KeyError as e:
+                raise ConversionRefused(
+                    f"A variable {identifier} is used multiple times - better not to replace it."
+                ) from e
 
         if suffix:
             ast_name = ast.Attribute(value=ast_name, attr=suffix)
         new_segments.append(ast_formatted_value(ast_name, fmt_str, conversion))
 
-    if var_map:
+    if var_map and not state.aggressive:
         raise FlyntException(
             f"Some variables were never used: {var_map} - skipping conversion, it's a risk of bug."
         )
@@ -131,8 +145,9 @@ def joined_string(fmt_call: ast.Call) -> ast.JoinedStr:
     new_segments = [fix_literals(e) for e in new_segments]
 
     if all(is_literal_string(segment) for segment in new_segments):
-        return ast.Str(
-            "".join(literal_string_value(segment) for segment in new_segments)
+        return (
+            ast.Str("".join(literal_string_value(segment) for segment in new_segments)),
+            False,
         )
 
-    return ast.JoinedStr(new_segments)
+    return ast.JoinedStr(new_segments), str_in_str
