@@ -196,6 +196,53 @@ def test_indented():
     assert s_out.split("\n")[2] == s_expected
 
 
+split = """
+var = {}
+a = 'foo {}'.format(
+    var.get('bar'))
+"""
+
+split_expected = """
+var = {}
+a = f"foo {var.get('bar')}"
+"""
+
+
+def test_line_split():
+    s_out, count = process.fstringify_code_by_line(split)
+
+    assert count == 1
+    assert s_out == split_expected
+
+
+def test_line_split_single_line():
+    s_in = """a = 'foo {}'.format(var.get('bar'))"""
+    expected = """a = f"foo {var.get('bar')}\""""
+    s_out, count = process.fstringify_code_by_line(s_in)
+
+    assert count == 1
+    assert s_out == expected
+
+
+split_kw = """
+var = {}
+a = 'foo {key}'.format(
+    key=var.get('bar'))
+"""
+
+split_expected_kw = """
+var = {}
+a = f"foo {var.get('bar')}"
+"""
+
+
+def test_line_split_kw():
+    s_out, count = process.fstringify_code_by_line(split_kw)
+
+    assert count == 1
+    assert s_out == split_expected_kw
+
+
 def test_openpyxl():
     s_in = """sheet['B{}'.format(i) : 'E{}'.format(i)]"""
     s_expected = """sheet[f'B{i}' : f'E{i}']"""
@@ -526,3 +573,72 @@ def test_super_call():
     out, count = process.fstringify_code_by_line(s_in)
     assert count == 1
     assert out == expected
+
+
+escaped = """
+var = 'baz'
+'foo " %s \\' bar' % var
+"""
+
+expected_escaped = """
+var = f'bazfoo " {var} \\' bar'
+"""
+
+
+def test_escaped_mix():
+    """Regression for https://github.com/ikamensh/flynt/issues/114"""
+
+    out, count = process.fstringify_code_by_line(escaped)
+    assert count == 1
+    assert out == expected_escaped
+
+
+escaped_2 = """
+var = 'baz'
+"foo ' %s \\" bar" % var
+"""
+
+expected_escaped_2 = """
+var = f"bazfoo ' {var} \\" bar"
+"""
+
+
+def test_escaped_mix_double():
+    """Regression for https://github.com/ikamensh/flynt/issues/114"""
+
+    out, count = process.fstringify_code_by_line(escaped_2)
+    assert count == 1
+    assert out == expected_escaped_2
+
+
+issue_112 = """
+'some {} here as {}'.format(
+text, placeholder)
+"""
+
+expected_112 = """
+f'some {text} here as {placeholder}'
+"""
+
+
+def test_112():
+    """Test for issue #112 on github"""
+    out, count = process.fstringify_code_by_line(issue_112)
+    assert count == 1
+    assert out == expected_112
+
+
+def test_110(aggressive):
+    """Test for issue #110 on github"""
+    s_in = "'{conn.login}:{conn.password}@'.format(conn=x)"
+    expected_out = "f'{x.login}:{x.password}@'"
+    out, count = process.fstringify_code_by_line(s_in)
+    assert count == 1
+    assert out == expected_out
+
+
+def test_110_nonaggr():
+    """Test for issue #110 on github - no change in code expected outside of -aggr flag"""
+    s_in = "'{conn.login}:{conn.password}@'.format(conn=x)"
+    out, count = process.fstringify_code_by_line(s_in)
+    assert count == 0
